package com.ynet.life.util;

import java.io.BufferedReader;
import java.io.EOFException;
import java.io.FileReader;
import java.io.IOException;
import java.io.Reader;
import java.util.Vector;

public class CSVReader {

   private static final boolean debugging = true;
   private BufferedReader r;
   private char separator;
   private static final int EOL = 0;
   private static final int ORDINARY = 1;
   private static final int QUOTE = 2;
   private static final int SEPARATOR = 3;
   private static final int WHITESPACE = 4;
   private static final int SEEKINGSTART = 0;
   private static final int INPLAIN = 1;
   private static final int INQUOTED = 2;
   private static final int AFTERENDQUOTE = 3;
   private static final int SKIPPINGTAIL = 4;
   private String line = null;
   private int lineCount = 0;


   public CSVReader(Reader r, char separator) {
      if(r instanceof BufferedReader) {
         this.r = (BufferedReader)r;
      } else {
         this.r = new BufferedReader(r);
      }

      this.separator = separator;
   }

   public CSVReader(Reader r) {
      if(r instanceof BufferedReader) {
         this.r = (BufferedReader)r;
      } else {
         this.r = new BufferedReader(r);
      }

      this.separator = 44;
   }

   private int categorise(char c) {
      switch(c) {
      case 10:
      case 35:
         return 0;
      case 13:
      case 32:
      case 255:
         return 4;
      case 34:
         return 2;
      default:
         return c == this.separator?3:(33 <= c && c <= 126?1:(c >= 0 && c <= 32?4:(Character.isWhitespace(c)?4:1)));
      }
   }

   public String[] getLine() {
      Vector lineArray = new Vector();

      try {
         String returnArray;
         while(lineArray.size() == 0) {
            while((returnArray = this.get()) != null) {
               lineArray.add(returnArray);
            }
         }
      } catch (EOFException var4) {
         return null;
      } catch (IOException var5) {
         ;
      }

      String[] var6 = new String[lineArray.size()];

      for(int ii = 0; ii < lineArray.size(); ++ii) {
         var6[ii] = lineArray.elementAt(ii).toString();
      }

      return var6;
   }

   private String get() throws EOFException, IOException {
      StringBuffer field = new StringBuffer(50);
      this.readLine();
      byte state = 0;

      for(int i = 0; i < this.line.length(); ++i) {
         char c = this.line.charAt(i);
         int category = this.categorise(c);
         switch(state) {
         case 0:
            switch(category) {
            case 0:
               this.line = null;
               return null;
            case 1:
               field.append(c);
               state = 1;
               continue;
            case 2:
               state = 2;
               continue;
            case 3:
               this.line = this.line.substring(i + 1);
               return "";
            case 4:
            default:
               continue;
            }
         case 1:
            switch(category) {
            case 0:
               this.line = this.line.substring(i);
               return field.toString().trim();
            case 1:
               field.append(c);
               continue;
            case 2:
               throw new IOException("Malformed CSV stream. Missing quote at start of field on line " + this.lineCount);
            case 3:
               this.line = this.line.substring(i + 1);
               return field.toString().trim();
            case 4:
               field.append(' ');
            default:
               continue;
            }
         case 2:
            switch(category) {
            case 0:
               throw new IOException("Malformed CSV stream. Missing quote after field on line " + this.lineCount);
            case 1:
            case 3:
               field.append(c);
               continue;
            case 2:
               state = 3;
               continue;
            case 4:
               field.append(' ');
            default:
               continue;
            }
         case 3:
            switch(category) {
            case 0:
               this.line = this.line.substring(i);
               return field.toString().trim();
            case 1:
               throw new IOException("Malformed CSV stream, missing separator after field on line " + this.lineCount);
            case 2:
               field.append(c);
               state = 2;
               continue;
            case 3:
               this.line = this.line.substring(i + 1);
               return field.toString().trim();
            case 4:
               state = 4;
            default:
               continue;
            }
         case 4:
            switch(category) {
            case 0:
               this.line = this.line.substring(i);
               return field.toString().trim();
            case 1:
            case 2:
               throw new IOException("Malformed CSV stream, missing separator after field on line " + this.lineCount);
            case 3:
               this.line = this.line.substring(i + 1);
               return field.toString().trim();
            case 4:
            }
         }
      }

      throw new IOException("Program logic bug. Should not reach here. Processing line " + this.lineCount);
   }

   private void readLine() throws EOFException, IOException {
      if(this.line == null) {
         this.line = this.r.readLine();
         if(this.line == null) {
            throw new EOFException();
         }

         this.line = this.line + '\n';
         ++this.lineCount;
      }

   }

   public void skip(int fields) throws EOFException, IOException {
      if(fields > 0) {
         for(int i = 0; i < fields; ++i) {
            this.get();
         }

      }
   }

   public void skipToNextLine() throws EOFException, IOException {
      if(this.line == null) {
         this.readLine();
      }

      this.line = null;
   }

   public void close() throws IOException {
      if(this.r != null) {
         this.r.close();
         this.r = null;
      }

   }

   private static void testSingleTokens(String[] e) {
      try {
         CSVReader e1 = new CSVReader(new FileReader(e[0]), ',');

         try {
            while(true) {
               System.out.println(e1.get());
            }
         } catch (EOFException var1) {
            e1.close();
         }
      } catch (IOException var2) {
         var2.printStackTrace();
         System.out.println(var2.getMessage());
      }
   }

   private static void testLines(String[] logLine) {
      String DEL = ",";

      try {
         CSVReader e = new CSVReader(new FileReader(logLine[0]), ',');

         while((logLine = e.getLine()) != null) {
            StringBuffer logBuffer;
            (logBuffer = new StringBuffer()).append(logLine[0]);

            for(int i = 1; i < logLine.length; ++i) {
               logBuffer.append(DEL).append(logLine[i]);
            }

            String var6 = logBuffer.toString();
            System.out.println(var6);
         }

         e.close();
      } catch (IOException var5) {
         var5.printStackTrace();
         System.out.println(var5.getMessage());
      }
   }

   public static void main(String[] args) {
      testSingleTokens(args);
      testLines(args);
   }
}
